
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
SWIFT module of the Python Fintech package.

This module defines functions to parse SWIFT messages.
"""

__all__ = ['parse_mt940', 'SWIFTParserError']

def parse_mt940(data):
    """
    Parses a SWIFT message of type MT940 or MT942.

    It returns a list of bank account statements which are represented
    as usual dictionaries. Also all SEPA fields are extracted. All
    values are converted to unicode strings.

    A dictionary has the following structure:

    - order_reference: string (Auftragssreferenz)
    - reference: string or ``None`` (Bezugsreferenz)
    - bankcode: string (Bankleitzahl)
    - account: string (Kontonummer)
    - number: string (Auszugsnummer)
    - balance_open: dict (Anfangssaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_close: dict (Endsaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_booked: dict or ``None`` (Valutensaldo gebucht)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_noted: dict or ``None`` (Valutensaldo vorgemerkt)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - sum_credits: dict or ``None`` (Summe Gutschriften / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - sum_debits: dict or ``None`` (Summe Belastungen / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - transactions: list of dictionaries (Auszugsposten)
        - description: string or ``None`` (Beschreibung)
        - valuta: date (Wertstellungsdatum)
        - date: date or ``None`` (Buchungsdatum)
        - amount: Decimal (Betrag)
        - reversal: bool (Rückbuchung)
        - booking_key: string (Buchungsschlüssel)
        - booking_text: string or ``None`` (Buchungstext)
        - reference: string (Kundenreferenz)
        - bank_reference: string or ``None`` (Bankreferenz)
        - gvcode: string (Geschäftsvorfallcode)
        - primanota: string or ``None`` (Primanoten-Nr.)
        - bankcode: string or ``None`` (Bankleitzahl)
        - account: string or ``None`` (Kontonummer)
        - iban: string or ``None`` (IBAN)
        - amount_original: dict or ``None`` (Originalbetrag in Fremdwährung)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - charges: dict or ``None`` (Gebühren)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - textkey: int or ``None`` (Textschlüssel)
        - name: list of strings (Name)
        - purpose: list of strings (Verwendungszweck)
        - sepa: dictionary of SEPA fields
        - [nn]: Unknown structured fields are added with their numeric ids.

    :param data: The SWIFT message.
    :returns: A list of dictionaries.
    """
    ...


class SWIFTParserError(Exception):
    """SWIFT parser returned an error."""
    ...



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00@\x00\x00\x00s0\x00\x00\x00z\x08e\x00\x01\x00W\x00n\x14\x01\x00\x01\x00\x01\x00e\x01d\x00\x83\x01\x82\x01Y\x00n\x02X\x00e\x00e\x02'
        b'e\x03d\x01d\x02\x83\x04\x01\x00d\x03S\x00)\x04z\x1afintech package not loadedsd.\x00\x00PYARMOR\x00\x00\x03\x08\x00U\r\r'
        b'\n\t4\xe0\x02\x00\x00\x00\x00\x01\x00\x00\x00@\x00\x00\x00$.\x00\x00\x00\x00\x00\x00\xa4\xdc\xf3\xdb7\x10V|S\x9bb\x94\xeb+-F\x00\x00\x00\x00\x00\x00\x00\x00\xe7\xfc\xe5\xc6c\x91\x87O\xb4\x1dmYg\xf8\x85'
        b'\x02\xde\xba\xd9\x16\x9aE\xfd\x0b\r\xe2o>\x8e\xc4\xaa=\xe0\x17o76\xe3\\\x8b\xae\x9d\x1c\x9bMu$9\x93\xcf\x7fi\xf5\xecl=\x9b0!\x11>\x88\xe7\xb6\x86\x05\x85M$\xf4\x0b\xf4\xccil\x92\x9e\xb0^'
        b"Q\xabcV!R\xff\xbacI\xc4\xcc'zn7\x90\xd2\x8c\xa0\xdc\xfa\xd4\x04K\x01\xa3\x91LWs\xba\xf3\xfc5\xd3\xf8\xbd\x96M\xefB\xd1\xf3+\x1e\xe1\x19a\x87dnHC\xd0bv\x1b[\x9ay('5"
        b'\xda\x1b\xb0\x921\x1aqI\xad\x10`\xdd\x02`\x13\xd5\xf9\xb8\xdd\x1c\x9c\xeeW\x18\xc1\x8d\xdb\x06\xcc\xf6\x88`\xea \xddK"\xf8(t\xf6\xd0N#d/\x10`\xd1%x\x9a\xea\xeca\xbf\xe7\xa2^#@p\x9a\xee'
        b'\x93\xa9~\x15\xb6|\xad\xaf\xde3#0,\x98\x1e\xc1\x16\x8f\x1f\xa1\x8f\xf3\x98"B_\x89\xbc&\xe7\n\xc2\xd9\x92W\xf6k?\xdf\xe8\xdf{\x08\x9e\xb0/\'\xcb\x83\xd1R\x0c\xca\x16\xec\xe7\x95\xef\x10\x80\x10\xbc>\xa1'
        b'&\x97\xbd\xbc\x90\x86:\xed \x1e\x06}\xea\xa4\xb9=\n{\x14B\x85\xc6\x00\xcav\xa5\x14\xde\x94\t\xe9\t\xb7\x1b\xe4,\x8eC\xe4\xba\xee\xa6+\xecL\x0fw\x04\xf6\xcc\xd4m\x83\x99\xd3\xab\x83\xd7~w!E\x9d\xe1'
        b'\xb1\xad\x1e\x93\x8e\x0c\xfe\xc6\xf3\x8e\n\xe2\x05\xc41X\xb3\xafE\x88\x8f\xed\xf9\x89\xb7\xcd\x92\x9b\xddK.\xc4%\xbd\xfc\xabM\x12\x01QA\x03\x17\x0e\x94\xbb\n\xb3\x15\xbcr\x8d\x8a%\xbc\x10\x11\x8f\x81\xb7\xe8\xf3\x0c{'
        b'\\\xfe\x11?$\xa3z\xbd\n-\x9a/\x91`\x18\xdc\xbe\x8e1\xa5\xa6\xf0&\xf0\xc1\x14@.\x9bM\x1a}\xf3\x8ajp\x96\xd1\xb9\n@\x00k\xcdPvD\xca\xb0\xcb\xcb\xeb\xf9\x99\xc8\x1e\x9bK\xd8\x9a\xbcI\x7f\xf5'
        b'\xaf\xe9\xc7\xff\xe9bT\x8fu\x1a\x901\x9a\x00\x83_\xbcCX\xd1$\xbf\x03\xc9r\x14y\xbe\x05\xbe\xf6\xd1\xc3\x0f\x17\xb2\x99\xfe)\xccH\x90|\x1ex\xb6\xd4\xb8\x83\xf7\xf7\xc3\x1d\xaa;\xa3Tp\xb0\x91j\xe6\x9f&'
        b'a5U\x10\xf8\xf3\xc1z\x1c\x98H\xd7\xba_\x0f1\xa4O\xf5\xef\x8b\xed\xfd3-\xe7^\xe3\xc9\xd2c\xe4\x00I7e\x84cxx\x1e\x00E+1u\xc7\xa8\xf7\xbdj5\t\x07\xb3\x19\x8a\x89#\x1a\xe0\xebd\xaa'
        b'\xceQ\x1b\xa5\xd2\x8a\xbb.DVm@\xa9\\,\x19\xbaid_\xdc\x8f\xf4\xd8\xce,\xd4{\xdf\x9c\xda\x9a\x12\x02\x07\x03\x1a\xfb\xef\xbd\xa9\x19\xd5\xc8D^foV\xa5\x18\xf8EOO\xbb"<?Y\xbfX\xf9\x05'
        b'\x8e\n\xf9;\x04\xffU\x9941$\xac\x0f\xea./sz4\xd9\xb8\x10\x95U\xa6RS\tc\xef\x0c\x93\xb10;\xf9\x89\x11\xf9\xb8H\x00`\xc0\xd0y\xa4b+\xf2\x92\xed\xd1C\xbf\x94\x00\xa3\x89\xda=\xd7\x0bv'
        b'\xe9\x7f\x8a\xb1\xa7D\x82\x05\xf68\x9e\xa0\xccy\xd9=IC\xee\xa9\x17\xcbG\x83\xa1\x92\x05\xe2\xbd[\xb5c\x13\xe6\xa4\xeb\xda\x8f\x9ay\xf8\xfd\x1d^\x93iCf\xcd\xf3\xb80\xed\xbb2S9\xa7St\xa3\x10\xc5\x89'
        b'\x1c\xb9G\x96M\xfcZR\xcd\xd1\x80\x00\xa3y\x0b\xfdU\xad\x95\x9f,\xf2\x9d6m\xa3\x00\xb7\x08\xa8\xae\xf11[^\xe2p\xb8k\x8e\xfd\x87J\xb5\xd0W\x8e\x84\x17\x14p\xb8\x10\x1c\xc9]\xd8\x19\x88[\x8c\x12O\x95'
        b'\xfet\x94\xcb\xf68\xfd\x90IY@zH\x0eaG\xc5\xd8\xe3*`?=\xdfpL\xc4?>\n\r},z\xe6\xc6\x9f\xcef\xd8\xf4\xc4\x14\x02\xc9\xb3\x9c$\x8f\x08\xce\xd9\x9f\xec\xb5\xac\xc1R\xee[\x81\xc1\x9e\xd0'
        b'\xb3>>\xd3\xa7\xf5a\xa6\xdf\xf6=\xc7w\xfb+\x8f\x0f\xba \xa6\x9e^\xf6\xf2\xa7\xcd>B(5\xdck\xb1#\x17#H\x82Cm|\xb4L\xb5!\x85\xd3\re\x1a\xb8d\xd4X\xc1\xa40\xfe\x9c\xde\x97Gf\x10'
        b"\xa2\xf6\x94R\xee\x7f?\xa1\xce\xd1\xbf\x1e2\xa2\xb5\xa9\xd6\xc4]Xl\xa8\xce\x93P\x12U\xe7\xa4\xeb/\x07\x9eo\xccw\xcfn\xda$\xa6\x01\x9a\x0b\xde?]_'\xb0?\xf7[z`\xe2\x164\x0bC\xd9\x07*\xfd"
        b',\x80V\x19%:+\x88D\x02\x9d\xa8\xad\x86\xfb\x01.p3?\x96\xce{*Y\x0c\xd2\xa2\xd5\xa9T(*\xcf\x84Y\x01.\xec\xa9\xab\xde\x86\xfat\x11\xd2vat\x1a\x8e\xa8E\xe1\x04\x17\x08J\xc5i\xabm\x15'
        b'\xc2Q|\xec\x8ch\xbc\xf5IXW]\x089\xaeC\x01\xa2 \x07\x86\xa4\xfc\x97\x19g9|\xceB\xc4\xdc1U6\xc2\x14P\xd4\x85u\x14\x97K\xa1\xbd\x95\xbd\xd9\xbfj\x8e\x8e\x95T\x9f\xee\x9b\x9f)oA\xfa\x02'
        b'\xb4H\xac\\(\xe4v\x804\\h\\t\xb9\xc9fmk\xd0{\xfft\xb4d\x0b\x93\x8fX\x0c\xa3\xe5\xe0tB\xa0\xb5\xc4\xc4\xc9\xf4!lL\xab(O&Ti\xa5\x15\xe0\xc2\xba\xe4\xe4(\x11\xb7\x04(\xb9\x9e?'
        b'\xe9\xfd\xcc\xa6\xdb\x0e\x146\xabc:\x110\x16QG\xe5"\xd7\xcfN\xf1\xa4\xa7K\xaaG\xc8\xc2\xe8\xf5l\x14~]\x12NA\xf9\xf0\\\xfcL\xb1\x18\x8a\xd1y\x81<\x042<n\x84\x86+\x03D\x01\xf6\xf2\x84\xc0'
        b'\x90 u\xe7*-M\xb2>\x95\xd5\x7f\xf8-\x1b\xe7KN\xd9\\\x7f\x1d\xce\xca7N\xfd^\xe9\xa2\xf3\xb0\xc5\x10J}W\x14Av\xa2Q\xa1\xb8{\xb23\xfd\x98\xc1\x1b\xd8Q\x92s\x0e\x90H\xd1\xfd\x8f\xb9w\xe3'
        b'\xb6\x82*\x9e\\4,\x12\x89\x96\xc6\xbb\xb5\x14w\xacv\x822\xc4\x9a\xacQ\xa0\xcei\xb8\xdd_\xf3\xb0\xb2#\xc4\xbe\xf1D%\xda+t\nknU\xbbQe\x12e\xd8\x97H\xb5\x15\xbd\x11\x84r\xb5\xe0\x08\xe5<'
        b'/\xc37R\xdd\xe3!_\xe9\xea\xd3[D1\xf8\xe4R\xd9\x02S\xeb\x86\xbe\x0co[\x05^\xdf\x15\x92\x8a\xbf\xf5\x17\rj}\x05#D\xa73:\xa6a\x91\xef\xf3]\x0c8?>\x81\xb5z\xd7/l4\xcbaF'
        b"\xefaj\xe5OaDw\xe2\xa9\xa92\xc2c\xd8]?,\xf8\xc8\x94\r\x1e4\x14\x9c\xad\x85\xa0\xd9?R\xd6\xd2\x8f\x8d\x01'\tf,\xff\xf0M\x07\x81\xd5A\xe3>\x1a\xa5u\x01@\xef\xffq\xe4r\x12\x0bF\xf0"
        b'\xc8$\x8e\x9c\xa3\xb4v\x9a\\\x81b\x89!\xd9\x7fo\x89\x0e\xfe\xcaQ\xf0\xda\xa4\x04z/\xf1\x9d\x08\xb51\xe6\xe0^\np\x9c&a\xa8\xf7\xa9M\x81\xe8F/~\xe6\xf9\xb0\x8d\xc5\xa3\xf1\x82\xael\x1c\x9d\xd5aV'
        b'n\xb3\xd8\xaf\x97\xbc\x9e\xed\xd5\xc5\x9bF(\xf5\xdd\xab$\x93Ct\xe9f\xa0\x14\xa4\xb9F\xe7\xed\x18\x96\x17=\xa5\xd6\xc9\x13\xea\xa5\xba8\x04\xc9\xb63\x85\x05X\xc2\xff\xd6o\x9f\xe6\x9b\xe3\xa3\xaa\xe1\x89\xdd\x99\x98.'
        b'~F/\xa8;\x7f\xd8\x01\x15R\xff?3:\x07\xaa\x95o\x07\x99\xec\x11\x9d]\xd2Q\xa81X|jy\x1d(\x81\xb1\x12X4\xb9V\xdc\xf3\x10;\xb3\x8c\xf09\x8b-\x97o-\xd5\xca\xd5GQ\xfb\x8d\xa9[\xe3'
        b'\xfc\x87e\xbbK\xeaq\x16:\xe5\xf2\\i2\xeeU\x0c\xb6\xfdT\x8e\xb1\xd0\x8e\xf3\xb8\xa3\x10\xaeZ.\xfc\xd4\x9e\xedr\xc5\x83!$q\x8c!]\xd7\x93\xd3\x95%\x9d\x8d\x8b\x18\xb7\x9a\x15\xc8\xe8\x14\xfd\xd1\xacQU'
        b'Y]}*4%\x14V\xb2\x84z\xb7:%\x97\nj\x8b?\xcc\xd2kT\xfa\xa4=\xad\xaf\xe7\x97~\xc6\xe0\x9cW\x08\xf0|*PYe\xed\xa9\xd8 \\\xc0\xc8\xc9\xdd7\xd4m\x0e\xe8Qn\x89\xeeN\x8e\xbaX'
        b'\xff\x89\x8e\xb85\x195\x18n\xd0a#\x8aD\x02\x85\xc3P6?\xe2>\xbb\xb8EC\x0b\xf8n9\x11A\x19\xc5\xb8\x92J\xadd\xae\x97*o\xc8\xa4Y%\xef\x93\x8d\x05\x8fmo/>\xc1\xa7"\x93|\x0b\xa5 '
        b'lvA\xed\xd7\xbb\xad5\x0bR\x95)\xa7&\xcc\x8c\x9a\x1e\xe74\x93\x91`qoR\x8c\xdb\xb4\\\xb0\xa5\xe7\x17\xc8\xd6\xb5\xdf\xca\xc7\xba@!>Z\xb9\x9c`\xe6|\xd6\x1c>B-\xe6IT2GVx\xbf\x18'
        b'o\xe2\xef\xc2\x97~!\xc0Im\xad\xcb\xaa\x14\xd0a\xf5\xa0\x01\x9e\x94\xcf<\\a\x9c\x1f\xee\xbe\xb2\xc3/_\xdc|Ul2\xb7\xb6\t\x12&\x93?\x10S\xbb{s=\xf7\xec\r\xd7\x08\x13\xdd\x96\xd4\x080\xcf\x0e'
        b'\xb0p:\xb8\xcd\xd9\xf6\xc2\xa2\x05\xe8pj\xf2.\x9e\xb4\x08g\x92u\xffs\xd4\xa8\xda\xaf\xee\xa4p\xb9\x12\x86\xb4R\xe2\xecrl\x98\xaf\xdf\x8a\xadPn\x8a\xa4\xed\x91h\xa9\x95\xf4(,\xec\xcc>\xf5o7\xaa\xf5'
        b'\xe7\xfc_\x8em\xdd\xa8R\xda\x11\xfad9\x80\x19\x9e\x9e&\x8b\xa6\x9fs\xbe\xbf\xa8o\xd2\xbd\xbe\xd17\xd9\xbbc\x84\x04\xc3\x0f\xc3\xea`^\xd3\x82"\x82@\x86\xe9\x9e#\x8e3K\x7f:\x8eR\x05+\xa8\x92\xeb\xfa'
        b'\x12\x0b>\xa1U\xad\x8e\x1a2r\xbfG!\xe7\xc3\xe4yj:\\dW\x02p\x93\xea\xed,i\xa0t\x19\x04\xea\x9b*4\xbb\x97F\xba\x93Sy\xd1\xdfA\x83\x9f\xe6E\xfd\x9a1\x12\xd2\xb8\x87ke\xb8e\xbd\xd1'
        b'_,3XW#T\xf7t}\xa3}\xf0J\xd9\xe0\xff\x0f\xf6\x0c\x17\xf9`\x050d\xc3Hcf\xc7O\x8c\xf84\xcaYWP\xb1%\xe6\x95-0\xf1\x1b\xf7y\x8d\xd9R\x85*\xceM\xaf\x83\xa9\x86\xc0\x13\xc0\x91'
        b'B\x8bM\xbf\xe1\x0e?\xf7O\xc3t\x05B\xdc\x87\rp\xd3\x0f?(\xaa\xb5+\x00\xca7}|e\xb8\xdbU!\x03+*\x7f\x16\xb4\x02\xbe\xeb[\xb0\xe1\xf9\x97\xc0TS\x88\xf5\xf7\xe6\x9a\x9c\x86|e\x98N?\xec'
        b' \xc6\xae\xd4N\xb9i\xba\xf6\xb3,\xa0\xaa\x1d\x06j#x\xee\xea![\xe2I\x9cA\xd0\xd3\xd5L\xe7\xb4\x9c\x9dx\x0c\x92\x10#,\x88$Z\xa2"?\x83!\xb7\x19H\xfb\x8b\xf3\x95L\xe4X\xfb\nD\x8c\x96&'
        b'^Y\xa2\x19\xad\x1c34o\xfa\xd5\x9e\n\xfdL\x87\xf2\x8c\xc6\xba\x8eo\x18\xe1$\x90\x80\x10o\x9ao(\x9e\x93\xed?Ko_\xd1Cj\xb9\x9f\xcd78K\xc4D\xee\xb1$\xe0\xe09\xa5\x0eMy\x95\x83U\x80'
        b"X\x98/'\xd7ua\xbd\xb0H\xdd-\x06r\xbf3\x07\nne(q\xd6$M\x01\x04\xf5\xf1\xc6\xae\x01\x82b\xc7\xaeU0m\xebq\xac<\x1d\x033_Et\xde\xaf\\\x9a\xdc\xa4T\xfa\x04\xa2\x16\xf3R\xe3\xda"
        b'\xb8\xe4Z\xdd:\x1bn\x98\xca0b\xd9\xba##\xd9\x02q\xc9v\xc0\x0c8\\\x90a\xef7\xc5\xf86=\xf1\xf1\x0c\x9e\x80Ew\xe4\xcb\xd7\xfd\xc5#\x84ZO}\xc8\xf9d8l4\x90\xab,D\x1f\x1d\xa8\xaf\xaf'
        b'\xf2\xa5\xb4\xf6Z*\xaa>0\xfbL\xac\xb6\x9bU:\xde\x0b\x977S\x94|q~?\xdf\xd4\x1d\xde3T\xd1\xd0+@\xc2\xa3q1\x1b5\x81\x14\xc7>\x93;\xf8\xebj\x86\x18\xf3\x06\xc3\xdf\xdc\xd6<\xb0\xc8\xa2\xd9'
        b'\x9c\t\xfd\x84\x95\xec<\x8f;k\xc2\xdb\xe7\x011\xbd\xb7\xe7\xf9\xfb\xd2\xc3\x02\xabg\x87\xef\x05\xb7,\xa1\x15\xe8@\x8c\x1e\x8a \x05\xeb\xeb\xc5m\xc5\xec\xb2^\xf0!_sa-\x12Dj\xff\xb1p!J\xa2\xabr'
        b'\xb7,\xb8\xb9\xb0\xa8rR\xe0E\xf6\xf9\xcd}\x06\x9f\xb9\x8b3 \xc1k\x85m\xff_\xdcl\xda\x87f$\xb6\t\x19z\x94\xd9\x11"\x10\x1fQ\xe1\x8dL\x04\xf0+(\xac9\xb2VjgH\xab\xdb9\x03\x9d\xf5U'
        b'\xab\xd9\nm\xf3R\x99\x9b3uV\xb8.\xee\x826\xfd\x88\x81\xaeO;V\xfb\xcc{\xdc\xbb\x03y\x9ad\xb6\xa2\xcb\xf0}\x1f\xd9\x02\x88\x04:AV\xb7\x12\xa7\x1a\x9b\xffU\x7f\xc78:\x7fd\xd3i\xbc\x08\xb1\xbf'
        b'\xc9\x91\xb6\xdc\xd2\xff0N\xd0,\x10s\xc4\xd3\x06\x1d)\x95\xa0\xce\x12\x1ew-\x9eGs\xed\xe1L\xad=\xc9\xc7\x99\x17\xd8\xfb\xe1!\xbb\x1d\xec[&\xd5\xe3\\\x16\xf7\xe9\xa6\xfc\xa0l!\x8e\xcc\x10\xc3\x14\x85:\xc0'
        b'\xdf\x1c\xf0\xef\xe8\xe2Q\xcf\x92\xc9\x8f "\xe4\xed-\x9e\xb2px?\x9dO\xa4,\x08$\x01\xdf\xe8\x1c\xcax3\xdax\xe7\x04\x92\x06\xd0jH\x7ft\x0e\x07\xf0\xde\xdf,\xe7t\x84\xec\xfe\x83$M?\xb2^\x07\x8d'
        b'/\x18\xdb\xe9\x92\x1e\xff\xd0r\xf5\xa4A_\x8b0\xa6\xac\xe7e\xd4\xde\x84w\xd4\x8b\xb1j\x158\xd5\xd6\x01\x1fFn\x10d\xab\xbdU\x9a@\x19\x98%\x7f@a\xfd(\x8f\xd8\x0fU\xae\xd2\x90\xf5\xfa%\xa9yt\x18'
        b'\xa0\xec\x00:&\x15\x13\xff\xba\\\xaa\xa6\xbaU_\xc2-\x9f\x10\xd1\x8e\xa2z\xe3\x9e\x1eb\x8es\xc8\x19e\xbc{\x16\xf6\x93\xcb\x04\x00\xc5\xb57\x92vU\tf[\x18ql\xab%\xd0w,v>M\xd1d$\x18'
        b"\x81\x9d5\xc4\x96\xac\x0ei\x85P\x1f=\x96A-\xa37\x8di\x14pVxE\x15\x13\xd5\xd3\xba\x13\x1b1\xbe\x80\xa4_qX\x00\x84\x106k0\x13'\xf5\xd0\xfa\xe0\xa6~\xc5\xf2DwR\x08\xd6\xf2\x15|\x90\xc5"
        b'%8\xadm~\xd2\xcez\xee\\PCB{\x84h\xfe^M\x1c\xdc\x8f\x88|\xb0f\xb2\x13\xb5z9\x82\x86\x17;\xcd\xc0\xa3\xda\x80\xa3L> \x93\x9e\xc0\x8b\xe0F\xdc[\x8e\xc6P\xc3X?9*\xcdIb\x83'
        b'\xec+tT\x90\x07\x07{?6\'\x0f\x88f\xaa\xaci\x9dE\xf2\x0b\x06\x86=i\x93M`\xc0Z\x86"\xd7\xb4\xca\xef\xd09\xb9H\xcc1(:q\xbf\xc3\xe0\xf9~\xe2\xf4T\xc9\xa1\x0f\xefKmj0AqQ'
        b'U\xb5\xb7\x1d\xc8>\x14\x8d\xf1\xf6\xb7k\xb2\x1d\xea1\x89\x91|0@\xb8\x1aO\xd6xjm\xc5\xdf\x16-f\xca\xfed"\xa4\x1f\x8c-\xc1\xf0\xc6\x7f\xb6\x16H^\xa8\x8b\xb2;\xf2\xe3\xc9\xe2T,+\x7f\xb4s\xd7'
        b'Y\xa5Z\x03O\xda\x8a\xd9b\xfch\xc0\xa1\xb0=8#\xa3\x9d\xf9\xbf\xe7\xa7\x85\xfa\xa8^\xc3O\xd1\xfe\n3\xf6\xba\xb8fX^`D\xefs\x08#\xe2\x02\x95\x89\xbckG\xc2\xd2n\xcbi\x1f:|Cp\x89\x83'
        b'$\xea\xfb\x11\x88\x02\x90e*\x0fq\xacp\x9e\xa2\x1c\\\xe3\xb3\xb3\xa0R\x8b#[\x85\x06\xb3N\x00;\xc8\xed\xed\xae\xbc\xc0\xf1\x95"G\x93\xe5\x9b\xd1\xe6\x85\x12@W\xc0\xaf\x05\xde\xcep\xb6)u\xc7\xed<1\xb3'
        b'\x16*\x9d~j\xe3\xfc!\xe4\x91\xe7\x18\x1a\x0b3\xa6a\x7f"\tA7\xbf\x01G\xf7tU\xcc\x93\xd9\x80\x8c\xb9\xb4\x8b%UV\x91\xc6P\x0ccI#\xc99\x05\xcbK\xa6iM\x94\xe7\x13\xcf\x92\x91>t\xfc\x97'
        b'\x99[\xb3\xe5\xd8\xb8<uj\xf6\xdc\x82\xe6\xac\x9e\xaaC\xfch\x10\x15\xe9\xb8\x0b{\xf6\xddl\x82\xe8\xa2n?\x93P\xab(\x9f\xc2_c\xe4X\xea\xe5`$\x16\xa5\xdd8\xda\xec\x1bI\xc4\x15qZ\xc6\x94_\x11R'
        b'\xd1\xd8\x85\xf0P\x03\x82=c\xc9WaF\x18\x85\xe0\x88\xb64\xf3\x81&I\x9e\xa2U]y\xb8\xd5\x98\xca\x12\xaf\xfc/\rt\xa2\xa6\x0c1\x7f\x9e\x83\xcb\xdduMoB\x7f\xcaw\ro\xcf&\x7fG\xf9\x84\xc4e'
        b'!\xc6a\xf5\x0f.?\x90\xa7\x9a\x00\x19xB\x98\xbf\xb8\xf8\x0f\xef\x03V\xdb\x8f\xf1\xafpeb\n\xf7\x03;\xdbi\x01@9\x1b?+\xad\xd6M\xe2X\x14\x07\xfbk\x93v\xec#\x10\x84%6o\xe3\x8f\x81"@'
        b'~\xe9\xa5\xeeS\xdf\xa3Q\xc4\xf8\xb3\xaf\x961\x1ft\xd3S\xf0\xe0P\xa6VW\x08M_\xea\xa30\xefM;\x84\xb6@\x18P\x0bJ\xe0\xb8G\xe3\xf1\xdb\xa9w\xc0\x83\xb0:\xfa{\xc5qt\xd0\x00\xf3\xee\x1eQ\x99'
        b'c\x8d\xd6\x8b\xac\x87\x14\x8a\xc7kPd\xe9+\xd9\xf8\xd2\x89\x0bZ\xe2\xf0\xe8x:|\x9d\xcaD\xc5\xbfk\x07\xc1\xacx\x97\xcbqL\x1d!a\xc0\xc5[\xa2\x1df\x97=\\\xa4P\xae\xcdkS\x87\xbaf"\xe0\xb5'
        b'\x1bC\xd2K\n5\xfb\x8bjg<\xa5Qg\x00\xba\xf6\xc3\xcb\xddJ\xbd\x8a"\xe0\xa2\xda\xa6\x83\xc5\xdc\x89)\xf8\xfb\x7f\x00=\x12\x17\x85\x18\x05\xf1s\x84\xc2\x0b\xf2Ft\x08\xf0G\x1b\x95\x982\\F\x87\x9d2\xd3'
        b'Y\xaf\xe1\xb2\xe3\x06\x13\xfa%\x07\x80\x02\t\xd5\xfeL9\x1c\xf6\xd6\xa4\x9bd\x94\x00?\xd7\xcez\xe8I\xc2k4$\xfc\xa3I.]J\xa4\x04\xe9+4\x96\xda\x1a[8\x9aM\x98\xba\xd8\x84\xb2F\xf3\x15m\xec,'
        b'\x066.,\x11OI|\x178r\x82N\xcd\xa70g\xb3\x0c\xecp\xf8E\x9c\x95)\xb4Gd\xda\\UI!<}A\xca_\xb7\x12`0 \xf7\xae+\xef\x92-\x16\xd244\xa0S\xf9\x9d;\xe9U`\x9cE'
        b'9\x18\x1f\x81F\x8c\xbb\xbb2\x91\x10\x84\xbb8\xb3\xac9\xdb\xc6F-\xa9\x18OK\xe1\xe2\xf7\xed8dGs\xb1y\xc7\xd7?\x9bV\x07{B\xb1\x8a\x99+\t\x98\xfe`y\xc0\xb4\xf5\xad\xab\x96(K\xef7]]'
        b'\xbd\x95\x170<\xc1\xb2\x7f\xfc\xfdY\xa4\xf3\xdb4\x13\xf8\x9e\x12_\xd4\x8d\x04c\x89\x8b\xaf\xf5\xbe8k\xe1\x9484T\xd8x\xd9\xca\xf1\xbef/\x14\xd4\xc4Z\xa3\xeaIe\xcb\xbegz\xaf\xa6\x04\xdf \xdf\xc9~'
        b'S\xfb\xcd\xd5\x80\x13\xc1a\xb77\xea);\xa4l\x9e\x9f6<\x1atVcy\x9d\xd8\xa8\x99\r/\xa9;\xb8]n#kY\x08\r\xf5\xb5\x13$\xe0\xfa\xf6\x9f\x1a\x87\xf3\xae\xeex\x80G%J^\xdc\xfc\xfeQ\x18'
        b'D\xf8\xc4V\xa0]\x8b\xdbo\xfcb\xa8\r\xab].\xd7\xc9\xc8\xbf\x1dgg\x83\x85f\x97\xbe\x06\xbd\xd8\x80\xd0\xfa\x86\x9a|\xfd\xfeM\xcb\xfc6\xc3#\xbf\xb7\x85\x97\xed\xce\xc1\xafH\xf3\x8fM\xac\x8e\xec\xdf`\xf1\xa1'
        b'\xe8=|\xbbMr\xbc\n\xf9g/\xd7\x1e\xday\x9d\x95\x1b\x17r\x18\xf9\xaeS\xafr,\x87\xad\xffD\x88\x13d\x18\x83\x02\xe6\x83\xc2\xe0\xbc\x0f\xf3\xfb\xdb\\F\xd6\xcb\xc2\xe0y\xdb\xe2\xbb\xe0\x16\x9c\\\x8e\xd56\xfd'
        b'\xc6\x90\xf5\x95<u#"\r\xdf]\x14<\xa90\xc3\xa0\xaaF\x9evr\xf7Q\xe9h\x89W_\x94\xcd\x19KR2EA\xfa\x86\xe1\'\xaf\x02\xc4\xbb<\xbe\xb7\xbe\x99\xc3^ \x89\xb6 W\xd4/a\x91\xa7G\xb4'
        b'\xd5\x8a\x9bNT\xdd\xa2\x91]_M9\xe53\xb2\x99N\x95\x1aO\x1a\x16C\xd6\x07\xfa\xfd\x85\xc9oW\xbbLF\xb8\xc3)$Ov\x0fW\xdd\xdf\xd1\x8e\x99\xbdmtA\x1b\xb6\x08\x9b++*+\x90h\xee\xda\xdd'
        b'\xbdG\x80\xf1\x1b\x88\xa1\x18\xaa\x1d\xd6\xa4IV\xb9\xac]\x06\xe6\x86\x00\xa0\xffRg\x84(-\xf0\x127\xbc\x0b\x1e#\xea\xc9\x12S\x02\xa3\xdb\xba`\xaf,\x02\x84D.<\xf5\xe5\xb4\xd3\xbeRG\xc5\xf0l\xe4\xa8\xed'
        b'/\xa5\xf4\x8a/\x1d;\xd9\xb6\x00\x82\xfc_\x08\x1a\xeaQ\x05V\xf4\xfb\xe2\n\x0e\x11\x00\x01\x7f\x84\xc2S\x85K\xe8\xd0\xc9\xef\xbb\x91#\xf8\xf8\xf8\x80\\\xbf\x7f\xaftZ&\x00\xd3\xb6\xbc\xd1\xba\xa6b\xda\xee\xd0\x8c\xee'
        b"\xf7\x82\xa9 \xe9\x00x\x8c\xd5\x90%2\x04\x1d\xc7x\x1b\xb1\xd9\xa2\xc86\xab\x80{p\xb3\xae<\xae\x9b\x96\x95'x\xd7[s\x9c\x06\xc2}i\xd3\xd4H\xd8\x07\xfb\xfc\xe1uz\xb2\xe5\x0f;\xefj\xa4\x16m\xa7?"
        b'k\x9a\x13\xac\xbc\xb5Az=\x11\x92v\x16(\x81\x1e^\x0c\xe4{D6\xdff-\xaa\xa7\x8f\xb6\xf8\x9a\xc2\xbc\x01\xc5\xdc\xb6\xdeO\xc2%C\x19\t\x17\xf5&\xbdFF$\xe3\xd1\xa1\xe7\xfbK\xea\xd5U\xd2aO0'
        b'\xb2\x88\x0f\xe3\x8c2\xfeR\xec\xea\xa2h_\xfa{&,\xb8\x11\xdd\\v\x83\xa1v\xbe\x13A\xcbG\x82\x7fH/Oc\xe2(\xe3\xc5\xb1@G\xd1\xf3RD\xdd\x93fqG\x01\xe2\x1b\x19k\xb9\xbf/\x14l`\xcf'
        b"\xf0\xfaC\xd9\x0b\xe6\xb8%\xab\xa5\xff\x80\x8d\x17\x8e\xc7\x8f\x94R\xd1\r+\x1dmu''\xe5\x14!@\x83\xc1_\xae\xfa\xcfvu\x93\x9f\xf6\xa1\x13\x0c\x93\x02?\x9a\x12i\xd6b\x9c\x1f\xb1\xb3\x95A\xf9\x10\x1f\x05\xb1"
        b'\x8b\xb4/;\xc4\x853\x84\xfa#\x0f\xcaX\xe5g\xb0\x02\x12\xbdOP \x07\x8b/\xfdn\xe7!\xaa\x89\xa5UR\xb84|,\xfc\xbb\x85\xb3\x98z[\x8e\x997\x9b\x82\x80,9\xac\xea=[\xae\x1a{\xcb\xa7\xd03'
        b"k\xe5\x1c\xd2\xbb\x9f\xfa\x14h\x1b~\x15\xab\x1f\x05\xb2}\xf2\xc8\x1fN%\x02\n\xd5\x14\x85\xee\xa1\xed\x9b?+,4\xbc\xf2\xea\x7fJ\xc1\xd5\xa4\xe9\xdf#\xf1cm'\xb1<\x9e\x05t\xa7\x16\x84\xd9\xd0\xe0\x8c\x92\xa9"
        b'\x1fl\xd6\x96\x1d"\xb3\xde\x1c\xde\xdeu\xb5s\x17i<\x1c@\xa6+\xb8\xc2\xf4\xca[\xc0\t?\xc61\xdd_M-\xb4\x12\xf0s8\x0b9\x93\xa8\xc3\xb7\x0e\xaf\x1b\xd5\xf6^\x06z\x10\x90_\x9a\x8aQ\xd97C\x0c'
        b'}\xe8\xb8\x184\xa6\x8b\xc44\xec\xf2\xd4/\xd0*\xef\xaa\xbcu&P\x8a\xa5\xb1\x8a\x14o\xa3*\x8f\xb3\x1d\xe9d\x1d\x17\x1dr,\x9cYHkB\xa0o\xa8\x13\xf8\xc3\xe6\xbd\x92\x89\xfbm4\xf3\x18\xe4\x9bB\x08\xaf'
        b'q\x86T!l\x99\xa1x\x8c\xe9\xd94 \x93\xfb\xcc\x0c\xb1f\x8fKC\x03\xb1[\xb4{\xc5t\xa8\xe8\xa7\x1e\x14\xa7\x7f\x92\xc0\x07\xa4I\x05\x04\xb3Sn\r\x0b\xa2\x82\xa9\x9c\xfd\x08\xce\x19+g\xa7KT\xf4X\x9a'
        b'\xa5\xcaS\n\x8f\x14\xc8_\x0f\x8a,\xa5\xef\xaa\x17_\x0e\xc4\x0eb=\xbdV|\x8d\x7f\xfa\xb0w\x1d\xa1\xf8\x85\x07\xbc1\x9a\xe7\xdf.\x8a{{\xb0\xc1\xc5~A\xdcx0x\xcb\xab3\x0e\xb8;69\rD\x9a\xc2'
        b'\xc7|/\xba\xb1vA\nFb=\x83!\xdb\x12I\xb8\xda\x90\xae\x83|\xc6\xc6i\x1f\xf5/o<\xa1\x93\xa3]\xad\xf3\x17\xeb\x880ox\x8c\xebL\xfc9\x87*}\xd6\xb0{\x0fv\x99C\x01\xf4\x9c\xbd\xd5|\xfe'
        b'\x1a\xac\xf3\xa1\x1d\xe1\xdb\xfb\x9c\x1d\xba\xc6\x9e8\xadX\x03\xb2\x10\x8c\xdb\xd6\xceK\x7fn\x1d?\xf0\xf9\x9af\x15\x00\xb8 \xd9\x07i\xfeJ\xd4<>de\xf4S\x87\xecD\x1cSG%C\xa4\x930\xf8k\x10o\x1d'
        b'0\xba\xf9\xe2\xbc\x80Q\xa8y\n\x88T\x93\x18u2\x16|\xf6\xf0\x1f_\x16\x1f\x9f\xe1\xcbi\x81 \x0fnI\xbf\xe0\xce\x93\xc8\xce\x87\xdf\x0eL\x83\xaeM\xb2L\x1c\x1dy-;fUJU\xf6N%FN\x01\xe9'
        b'7\xb3\xc5\xa0\x07\xd3\xc2\x95\x08u2\xc2:\x1d\xcd\xa0\xbd?\xeb]r\x1d\xfb\xd1\xe2q\xbf\xf4s\xc9\x12\x1a F\x9e\xb7\x10\xa1+@\x94+\xb1}\x9d\x82N9(\xc4Jl\xd8\xc6\x0b\x00\x8a\xe8\xfa\xc5\xaaB\xd5\x9c'
        b'B~\x03V\x94\x1d(\x16b\x8f\xb0\xbb\xe9\x8f.(J\xb6\x0c\x1fJ[\xa4\xee,\xbf\xdd\xb0\xba\xeb\xb8\xed;h%\x90U\xb6\x83\xd7\x16b\xed\xb8{\x95\xdco\xabY\xb2\x88\r\x85\xfd\x0f\xefRmG\x1e\xf09e'
        b"@m\x00\x8d\x89;\x86g\xd2qr\xd6\x12\x0c'\x97\xe1/\x9d\xb3\xcf\x80\x1c*_\x9a\x80\xc3\x81zE\t\xe4\x03\x16\xe0\xd9<VD\xfb\xb4\xd0\xf7\xa4j\xdb\xb3\x8aTy\xef(\xbdh\xae\xf6{+\x1b\xe0\x8bW\x1b"
        b'\x19Df\x86\xd0\xff\x9f\xdc\xc7\xaez\xd4\xb7F\xe1\xcc\xc3\x89\xfaq4\xbd\x9eKX\xc0=\xda\xaceK?\xb0\tv4B\xfd\xe5iN(\xcd\xaf\xc4S\xe6t\xa2\xfdw\xe1t\xf7Vt\xef\xbb\xbc}\xceW7\x16'
        b'\\\xc4\x01\xeb\xe0Lr\x9c\x05:\xe0PY[\x16\x97\x11SDp\x04#6\x18\xaej\x90\x12y\x12\x00\x8e\x96\xd9\x03\xf8\xe5\x01$\x90.i\x0e\xb0\xaao\xe6\x9d\x0f\x88\xf6b\xa4^\xf8\xf9\x8a\xe2\xd7k\xbe8\xe4\xed'
        b'\xd7\xfb\x16[\x8b\x0f\x9e\xe8!\xa8\xb9\x84\xed"\xf3c\x1cI\x88gS\xd2\xf5=\x99\xc2\xccUugUB@\xc5~Q\xc1\xe6\xef\xe5\xc2\x87V#n\x88)*C\x11d*\xc6UfC.\xb4\xc3,\xdb\x8d\x9eF'
        b'\xc2\xd9~b\xcf IJ\rv\n\xf2a\x0e\xc9\xa65\x850}0\xd4\xd2b\x817Y\xf8Y\x96\xfcc;hF\xec\x93\xcc#\x10\x0e\xfe/\x12\x8e\xf8\x8f\x8b\xa6$\xad\xcb\xc456\x9c0\xc2\xd6\xba\xd4~\xec\xf3'
        b'\x8d\x02\xa1\t7;\xfc\x9dP\x17\x9d:kE\xe79\xa5$\xc5,S?\x9e\\\x0f\xe3_\xaa<\x96\xbd/V\xf8\xe9\xee\x11\xe8S9\xc2\x16\xde\xbdk\xf5\xe6\xc6j"\xebw\xbc&\xee\xad\xea\x99\x08`V\xb7\x89='
        b'\xcd\xf2\xc9\xb6\xd8\xd1\xe7\x00c\xd7\x10\xd5\xa2EH~\xcd8U\xb8n\xae\xd5I\xa6\x14\xdb\xa4`j\x10\xf2C4nA9\x9a\x18\x86w\xf9\xf8|3\xd0\xbb\xde!\xb0O\x00\x0b4z\xad\x96[\xa3\x83\xbe\x9a\x08k'
        b'\x89\xa6\xe5L\xef\x08\xed\x96U\xb9f%\xfezte\x92\x1ep\xbe\r\x0e\xb7\xd9z\xd2\x04"U\x16`\x06\xaa)\x19?;\xb4\xee~\x81\x06\xde|Kv\x04\x83\xa4z\xd7\xcc\x93Xj\x8e\xce\xde\x87s{\xe4\xd6\xc7'
        b"\x8e\x8b\xb0\xaa\xd7w\xc3\x0b\xb9n\xc5\xeb>S\x07\xf2\x98\x9f\xd6\xd7\x1f\xdfW\xdfP!1\x90f\x7f\x1a\xcb\x06C\xa5\x93\x99\xa2\xf8jg\xe3\x0cj\xb7N\xc2\xd0k\x7f\xf5\xe9!4\x88r\x0c\xa0\xa4'P\x1bu\x0c"
        b'k\x00e\xedj\xba\x11t\xfa\xd3\x02[\\\xb1J\xd6\x15:%T9\x14\x07="\xb5\xca\x11xx\x95\x93\x9e\xd5\xd6\xcfC\x8fc\xa3\xb9\xb9t\xe5\xe7L\x04\x10\x94\x9b=\xaa\xdbQd\xdb5\xc7\xdb\xecY\xcaWR'
        b'\x08\xb4\xd6(\xfb\x8b \xe9\x87C[\xf9\x9f\xcc`\xb6\xb5\x82^*\xe5\x949,\xc0\xd1\x91\x08\r\x91.\xd2\xad\xa3 \xa7p\xd5\xac\xa3\xcb\x9bZ\xbdt\x90\xb52+\x0e\x93\x85\xed+\x02/tWp\xbc\xe8\x06\xad^'
        b'\xc6>\xb1\xda\xa5\x9e\x01n\x02\xfa\xed\x04\xa8\xfa\xb4C!\x9d\x91\xae\xb2\xee\xb0\xea\x00\xee%y\xfd\xeaP\xf6\xc5v`D\x03\xc6\x0cp\x0b\x1d\xc616\x9bX!\xe0\xb3\xee\x00|t\xaf\xc9\xf4\x0b\x05\xa9\xec\xfc\x1b\xe1'
        b"SY\xa7P\xfcaA\x91\x7f\xdd\x1a\xaf\xd9\x14r\xec0\xd1\xafw\x8b'q\xed\x04\xf2\xdb)h\xe8,404\xac\x0ch\xe0;]\xaaX:\xf6)\xec\x04\xbe\xf2=\x85\xf1\x9f\xf2@lQ\x14\xceM\xec\xab\xc9H"
        b':\x92\xd2\x90?\xbc\xa7\x92S)\xf1\x9b?\xe9\xc7I\x8a\x87\x06\xc6\x0f\x9e\n\x7fy\xdePG\xbcP\x8e\xef\xa4F\xf9q+#\x81$h@\\\xfe\x8f\x0b\xec\xd8\x0f\xcf\xd9:Rn\x8f\xce\xef\x05I\xe0j(\xc2\x88'
        b"X\xf5\x80\x14\xa5\xaa\x82\xb9C\xd1Fn\xcf\x97\xce\xe9?^\xa8\xf3\x95\xe1IH\t|\x85\x96!\xeb\xb9\x00d\x15hd.\\\x84\xbb\xd6WPQ\xc2\xfc\xc2'\xcfn\xc1-\n/\xa8\xad\xeb[\x8c\x8c\xb9\x8d\x83Y"
        b"\x97Uum\x064\x03W\xc2\xf5\x95\xa1fu.i\x86\x8b\xf1\xa0\xae\xbaW\xd5)l\xdanf2\xe0\x10Mid\x85]7'\x16\xad\x11J\x04h\xad\xdaJ\\\xc2\xb4\x1d\xab%:\x1d\xdd\xab\xc4\x11[\x0e\xa6D"
        b'\x95\xd2\xaf\xa1\xaa\xd5\x0b\xa7"\x04\xf3\xc5\xa5\xcbt\xe0^i\x9f\x13\xae\xde\x96\xac,\'|\xe0\xdf\xe1\xe8K\x99\x1f\x11"rB\x04\xca\x1a\xeb@\xce\x87\xdc\xd9m0\xb3\x03\xd49-\xc0\xc9\x98\x96\xa6\xa3\x07C"\xf1'
        b'\xa7nvF\x0fQ/CS\xcf\xfd\x8e\x86\x15\x94F+\xe6b\xb8\x11c\xa1\xb1Z\xa1q\xe0\xe4O\x8d\xe9VojT,\x87<\xc1\x80\x8e\xed\xbbH\x87\xcc\xe1\xaf\x9e\x8bY\xa8\xe4\xc0\xafG\xc7w\'"\xf3\x8bQ'
        b'\x85\x94);\x87\x84\xf1\x1d\xb7bTE,\xa9\xb51`77\xb9\xd4\xeb\x19,\x93w\xdf\x93^\x1d\xd1\xbc\n\xf2(gN\xf6|M\xabja\x89\xbf/L\xad\xd8k\xa3o@y\x89\xb6\xfb\r\x7f\xca\x08\xb3\x87\xef'
        b'\x1a\x0f\xf1\xb8s\xd3z1\xff\xbdm\xba\x1b\xf7\x9a\xa1\x0b^\x0ba\xf3\x9d\x1adp<\xd1^#\x10\xd7_^\x0e\x99\xea/\xd7J\xe4\xe07r\x0f\xd7\xa3\x9f\xcd\xceG\x07G\x82\xe2\x0eu\x92\xe6t\xbcGF\x93\xcd'
        b'\xa0\x85\x9aa/(U&@\x8duU@\xe0\x82\x12l\xdc ZI\x15\x9cBN\xce\x91\xf7j\xdfs\x9dP\x16\xd95\x10\xde\x93\x10\x9c$|\xdc\xe7\x1e\xf4\x7fYss\r\x1c0\xb2\x98\xba\xcb\xe3b\n^SL'
        b'\x16\xceCX\xc9\xec<\xff\x1a\xb7u\xfc\xed\x9a?\xe63\x9ch\xbb\xd1\x0fT\xfa\x08\xf2\xbfPP\x9a\x923\xc4\xef\x7f!A|j\x0fxG\x9el\xa3\t5\xe3\xb7\x08TK\x91zt2\xc2\xa9\t\xf6A\xc4CQ'
        b'd\xc6\xae\xbe1d\x82\x92m\x88\xa2\xee\x01n\x87\x17\xebNS\xe0\x81}H\xe6\xb4\x82\xd4^\xde\xd8V\xae\xe7L\xba\xee\xf2Ju\xe0\xa2c\x0f\xc3\xe1\xa9pIF<\xbc\x94\x96\x85\xd2\xee\x9b\xdc.o\xa7["\x0c'
        b'\x12`\xc8\'U\xb7\x0e\xab\xe7\xabGj\x1e")\xd2\x81+\x13\xbbr&s\t"\xa9\xa1@\xb2Z\xb5P\xd9\x8a}]\xdcg\'+\xdb=[\xb6S\xf8\xd9P\xccZ\xce&\xdc\xb0\x12Q\x1aFpy"k\x8f\xfc'
        b'\xb7r\xde&\xdd\xaf5Uv\xde\x047g\x8a\x7fy\xe1R\x83s\xc2\xab\x93\xff\x9c\xff\xb8P\x0e\x13\xe4\\\xe3\xa7\xb2\x92\xcc\xb6\x8eN\x9c\xe2D\xbe\x89c85\x16\x93\xb8\xc6\x0bI\xabP\xc8Ez\xba\xc5ZR^'
        b'\xd9p\xb1\xf5Po\xb3\xa5y\xbc\x05\x88\xe3,\xdd\x94\xfa\xab\xd5\xd5\xab\xb5\xad[\x1b9\xe8\xa6\xb0\xa62S\xf5Y`\x0cR>ZO\xd0\x9d\x99G\xc0y>p\xcc\xb3g\x8d\xd7a\xa1\x12\x18\xee\xc7MsN\x04\xa3'
        b'vv\x10\x12p\xa5\x9a29\x8e\x84\x8e=\x9e\xe4\xacaU\x85,SW\x86Y\xb7v\xfd[\xfb*\xbe\x1e=x:\xe7\xf2\xa9\x0c\xae\x88\x80{T\x13\x86\xdd\xa7s|\x00)\x84iO\x83`"\xd4\xe9(\xdcUW'
        b'u\x1a\x1d#\xe6\x80\xc9i}#d\x81\x13\xd1&\xaa\xa7\xb8L\x88\x82r\x0eA9h\x16"\xd9\xf8\xa7^\xa4}v\xealo\xfc\xb0?\xbd\xd5h\xfa\xbd\xa0\xd8\xe26\x0eR\xd8\x8dK,\xa8\xab\xdd\\T\xe2\x81\x1d'
        b'x\x81^Z\x171[De(K\x95\xeef0\xc2c\r1%\x90\xa7\xa3(\xf4\x00\x1c\xcd\xa7\xa4T\xd8\xc7A\xae\x0eg\x0c\t$\xc7\xc2\x80\xac\xee\xee\xc1\xa0\xef\xbc\xaf\x90n\xce\xeb\x9bX?E\xf0\\\xdbb\xdc'
        b'\xa7\x13\'\x9fZ\xae\x84\x1dF\tM;\xfc\xc4\xda\xd9SS\xbeb\x98\x87\x86&\xab\xef\xb0\xb3&>\x00\xc8Y\x1dB\xa7\xa0>\x05\x0f\x7fZ\x80";dS\xcb.\x96l\xd0x\x04\x01\xdft@\x0b\xd7\xa8\xd4\xd0\x19'
        b'\xfeZ\xfb\x91r`\xe7\xa7\x13\xe66\x0bS\xbe\xff\xa5\xda\xe9\xbaV\x94\xec\xbd\x15\x91@\xc1\xc9\xc3\xe1\xf3\xfe\x01\x15\x90\xcb\x87FI6\xfb\x8a\x7f\xbfY\nu\x9d\xd3\x8e\x98\xb7\xb2\x92\xb5\xca\xfd\x10\xe7\x05\xa9\xaf \xbc'
        b'\x80\x9f\x12\xa3;\xda\x9aP\x18}\xad\x88#h\x00\xa9|i\xb0\x82\x8e\x80Md\xc8c\x8a\xb4\x03\x9f\x1a\xfc\xd7\xbd\r\xd3o\xf8\xa2>\x84}\xe4]\xef\x86\xb7b\xe2\x1f\xe6\x7f\xe3\xce\xa0\x06\xb1V-\x9e\x83\xfbx\xba'
        b'\xd2S\xd8\x19\x8d\xf1=\xc6h\xeeA\xcc?ds\x94Um\xda\x16\\\xbf\x1c<\xa8\xb4\xe9\xd8]S&\xc8\xea\xd82@d\x18E\xaeSi\xc6\xaf\xcb\x0fQ\xc8\xb0\xcf\xac=\x89\x86\x12\xce\xa7\\\xb3L\xf9O\xf11'
        b'\xd8\xba\xb7K\xc2op\xe4\xd3\xa9f\xbc\x90\xc2\x02F|]\xe5\x1a\\E\xa3Hxw+E\x84\xe1"\xa5\xf1m5\xdb]\x8c\x19O\xee\xf3;\xf0~\xb5e>C\xf3\xf1\x12&/\x81`\xc7\xff\xe5\x92^\xd6$\x89'
        b'\xf9\xed\xd6\xd3\xcbr\xa7\x15\xc0D\x14\x16\xa45(=\xee?\xfd\xf9w\x136\xb8p\xb6\xae/\xe2C\xd2h`d\xdc,3\xec\xda\x0cQ\xdd\t\x99W\xb0\x0e\x11hGj\xfd\xacO\xeb\x02+\xb3q\xa4>\xb3\x9c\xcc'
        b'\x13-\x9d\xc2\xef2\xe9\xde\x07$\xbd\x02\xfb\x99\xdb\xd5i\x85\x0b\xdf\xed\x82\x8c5\x18?L\xdb\x12\x1e\x11\x0c`\x16f\xe6\x15\xe5\x0c\n\x83S\xfd\xc2\xdfc\x80\x8a\x8d\xcd"\rX\x92gf\x86\xfe\xb0\xe4\xf6B\xed('
        b'\xaa\xd2\xf2\x86T\x7f\x93+P\xb7\x0brv\x01\r\x92\xe7<\x85\xd8\r\xf0\xab\xefH\x15)\xb1\x8dib\xce\x1c\x0e\xcd\xd7\xf2\x92D37\x81@\x84\xeb44\x9au|\xeb1gS\xcd\xd1\xb2\x12\x9aXr\x90\xcc\xfe'
        b'\xecK\xcc3o\xe3\x03t\x0fUY\xdaE\xae\xd8\xbc\xab\xa5^jz\x9e\xf7\x0cy\xb2\xb0\xc7\r\xa0\xecF\xbdD\xff\x9c\xa3\xe6\xbc\xdd\xd9\xa7\x1aA,`\x80$4\xe8\xbe\xff]\xf5\x18\xccl\xd6E#\x9f\xe0\xef4'
        b'\x9d>\xa3S\xa7\xa5y\x85\xca\x1b\x08L\x82`&\x98\xb4/\xb8t\xbcd3\xfe\xbe:@\tA#\xf6&\xf9:\x17ln\xd1n\xcd7\xc8\xa96\x99F\xce\xd6\x97\x82kM\xf7\xc4m\x19a\xd6\xe6\xad\xfdQ\xc5\xb6'
        b'\xa4l\xa7\x95\x93<Q\x11\xca\xde\xf0\xb5@\x10\x05\x1dqz\x9e?\x0c\xf8\xff\x86x\xab\xd3}[\xa9)g~\xe2P\xc7\xc8\nkV\xdeXz+G\x17o\x96"\xc35\xe8\xb2\xcc\xf1\xf7D"F\xac,\xc8\x94\xed'
        b'\xdd\x95 \xf6\xeb\xc53\xfd\x10\ra\xd4}\x961\x8b\x93\xed\xbb\x1a~\xb9\x19.\x96=*\xcd\xc9\xb9\xb3N#.\x7fB\x8b\x8f+_\x99i\xfd\xc9\x12\x13\xd1\x90w\xa5\xdd\x1f\x91O,\x1d\xeb\xc1\x12\x9d\x84S\xf0Y'
        b"\xcad\x87\x81\x8c\xff\xa5s'\x80\xe4I\x94\x87DH9\x92\xbb\xbb \x14Wk\\Vv\xc8Q\xa4$\x94\xf1\x97?\xaa\xf7p\xecf<\x9d\x85\x10$\x84\xed\xd4\xc4l\x16\xf8\x0fWgu\xa7\x07g#R\xdd\xc4s"
        b'\xa1w\x9f\xa9\x98U\x14\xdf\x0c-\x1d\x8eA\xf9\xa5\xcf)\x8f\x9f\x82V\x9f\xb7~\xbc:\x81\xb4\xc9\xc5}\xaa\xea\x1e8\x12\xc4\xf7\xc6\x184B6B<3\x0fR\xef\xc6\x16\xdd\x9c\xb48\x07D\xc3\xe0$\xce\x95\x1d\xc4'
        b'\xa3\x0fs\xc28\x8b0\xf4rwu]\x12\xa8r \xc9\xde\x01\x80H\xceN\xbd9\xf3\xe8^\xb1\xb9\x1d\x19\xba\xa6\xcb\x02\xe0\x97\xc9\xfb\x80>\xd3X*\xd0)\x01\x07\xff\xec\xacxt\xf9\xc0\xae\x1c\xe4\xb9\x00*iF'
        b'M\xbaV\xb5\xd5/i%\xb0 @q@3q\x03\xc7_\xda\xe0\x1fy\xa5\xee\x96\xf13\xc6\xb4\xc1^\xd1\x1dvC\x80\xcf$\xc7hx0?_\xa9\xc2\x00\x11\xfcm\xc6\t\xbd+#\xd4\xb2p\xd5\x0fMj\xb4\xa0'
        b'q\xd9\x7f\xbd\xa0zl\xbc\xbbz\xa8\x99i\xe1P\x8a\xa3\xa4Y;\xc6\x15\x1e\x00\xe0\x97X>`.\x00\xe3\xaa\xca\xcd@\x85x\x82\xa6\x85\x9f\r9\xd9 \xe2\xb0K\xdf\x81\xb6\xd5?\xf9!\x03\x19~\xd0\xf3\xc6v\x15'
        b'\xff#\xed\xc7\xe4\x17\xb6!\xe8\x99\xccv\xe5[\xce\xd8,t\xc7p\x06\x98\x92\x7f?B\xd0\x13\xfa>\x8b\xe9\x034\xcb|$\xb0\xa0\xa2\x10\xfd\x03\x9d\x98\xe3K\xba\x9d\x06\xf5\x83\xb20$\xe4\xff+\xb8\xa8(\x07\xd1\x9b'
        b'YD\xf7\xfdZ\x0e\x06^\xf3\xeco\xf8e\x7f\xae\x93\x0c\x0e#\xea\xdcH\xd7\x7f\xd9\xefp\x11F\xfbd\xa8\xff\xdc\x1b M\xdc(\xdc\x86\x7f\xd6\x0f\xf9\x84\x11\xfaD0\x82\xff\xf6M\xf5\xcc-\x1c`\x83d1\xf3\x07'
        b'\x95\x9f\xb2>3\xabQ\x97G\xfe\x94\xac3y\xfe\xf9\xb0\x7f\xd5M[\x1aHZ<\xde\x9c9\x875g\x9a\xbd\x08\r\xf6)\x97\xaf~[&yS\xa4\xf6\x9aC\x08\x08\xa9]\xf4\xd3\x97J\x1a\xbb\x06\xbddty\x8a'
        b'.@\xc5\xb0d\xe7T\xed\xbdt\xfd\xe0\n\x15=\xdar\x1a{:\xf2<\x86]%s\xfd \xc1\xce\x7f\x04\xa0\x9e\xdfj\x87\xec`\x04\xfef\xdbg\xe2\xc7|D\xb0\x1e\xf3\x95$\x16w\xca\x9e\x13Y\x01\t\xed\x9d\xf2'
        b'\xedQ@\x82c\x01U\xac\xf8\xa2"3\xb1\xed\x841Sc\x0eX\xf2\xecN\xc2#\x1c\x1d\x87\x9e\xd7r\xd6\xbez\xbbJ\x84\x87\xaf\xe0\xf6\xa9>Z\x89g?{\xd8\x9e\xb9"\x1a\xe5\xa8\xde$s+\xc4\xd9\xc5q\xbc'
        b'\x0c\xc9J\xbcM\xcd\xd2S\x8e\x856\xe4\xf7\xa4v\x83\xca\x80"P\xd5\x8c1tu\x8c\xd9\x86\x9a\xb6\xba8>\xbe\x03c\x11;\xa6_\x87"L\x10G\xad\x1f\x85\xb8fKUK\xbc\x97\'\x10Y\xf8\xc2\xe4\xd5\x83\x1c'
        b'\x00\x93\xec\x92\xc0<\x9e^8p\x9e\xd4\x1a\r&_\x08C8\xd2\xb2\x10\xb9\xd2p\xe2\x12\xec\xa1\x86\x05F\xac\xb7\xc9\x91\x9c\xa8\x14\x9a\x01\xcc^_\xd2\xe6\xde9\xa1\x07\x0bg\xc8\x05\x85\x9b\x0f\xa6;\xef\xa4\x88[\x82'
        b'\xb9Y\xde\xe2`\xb9\xaf\xa4\xbb\xb6\x99\x91\xe7]\xb2\xb3>\xe0\xbb\xa4\xb3\xba\xbe\x0c\xaf\xb0\xfd\xaeF\x94\xad{\xf8\x94Te\xa9\x86\xca\xb5\x00f\xb9~\x01\xc7\x1e\x03\x0e\xd5H\x84\xdd\xde\xef\xe7\xd3\xa1\xac$)\xf3\nI'
        b'u\xa4C6\xe6Vg\xd5\xa6\xff\xc7.\xba\x86\xe8##\xa1,\xc2u\x8e(\xdd\xe8\x8b\xc5-%\xe2r\xfd.\x0f\xfbDG\x14\xff\x1f\x80G\xa6#\x84\xb3\xf7\x05\xc7\x91ju\x87\x87\xad%\xe1J\xed\x1d\x07{\xfc\xd0'
        b'\xc2\xdco\xfb3\x86\xcef{\x13;\xd0\x16\x90Q\xdc\xa4\xaf\x18(J\xc0\xe0\xd6O\n\x08\xe0\x15\x0f*\xcb\x89k\xc3d6j\xc8\xf6s\xe2E$\x1d\xd1e\x8fgoM\xdb\x82<\x86\x9a\xb3\x99W\xb6\x9b\xbc\xc0\xe1'
        b']\xcc\xdf\x12\xa4\x1b\xae\x9bz4\xf8~\xf4\xff\x8d\xf5\xac\xcce\xda\x1eL-j^\x81Z\xd6h\xac\x03>\xba\xa8\x07\x98\x98\xee\xb2\xac\xb3R\xe6\x84\x7f\xe1\xb8k?\x11\x12\x1cQ\xc6\x03\xc0\x89\x02\x9c\xeb$/\xac#'
        b"3\x06\xbbB\x12\x14\x05\x86\xa20\x07f\x14\xacL\xd1r@\xaf\xee~cy\xa7as\xe3\xe3\xd3v4d\xe8\xc3>\x80\xbe[\xd8J,\xd5\x9f2\xcb\xa9'\xb5\x8a\xecK\xe6\xae\x19\xaa\xd0\x9d\xcb\t\xe1^5P$"
        b"\xfdDjE'\x0b\xbd\xed\xec=\xcc\n\xf6\xfaJ\xb7\xc5\x15\x90\x1c\x1b_\x1c\xdbt\x94\xc3-\x82y\x955\x9f\xdd\xc0\x83\xee{7\xd7E:j\x82\xda\x9b\xac\xbe\x80\x13-\xd29i\x02O6\xa1\xb3\x12\xc4\xcc$\xa5"
        b'\x0b\xa2\xa7Ta\xfd\xdc\xb6jU\x90\xbb\xf0\x13n\xb5T\xa3}\x83\x96\xb8\xdf<Z\xc5\xe9 \x00\xd5m\xea\xf5\xd9\xda\x90\xe2\x08\xd3\xe4\xa4F:4\xfd\xb2\xd8\x9e\xa9\xcbsX\xb4g\xdb\xc8\x99\xdb\xb4qA_)\xaf'
        b'a\x1f\x81+}\x86\xce\x8d\xab\x12\x9b`%\x03\xa5H\x96\xdf\x1b\rq\xcb\x9405\x0e\xe2\xcb\xad=\x93\x88\xce\xa2\xfc96\x16FfQ<Zr\xf8\xf1\t\x16L\xc1,\x19\x91]\xf8\x9a\xb4\xf9eu/i\xef\xc6'
        b'\xa1\xa7\xc0K\xab\x92\xaf{\x81X\x1e\x8b\x8e\xfeWA\x1d\x1b\xdf<f$\xe08\xee\xd1\xe8&\x80\x05\xe6\xee\x7f\xe6\x02c$i_\x90\xcd\x10\t\xac\x1f:\xc0K\x87\xfeh\xdds\x92\xdb\x15&%Nj\x1cdE\x7f'
        b'H\\\xf7\x80Fd\xc5\xca\x9c\xd7\xd7\x1b\xe7 9\x8c\xba$\x1d<\xca\xd1j.\x891[3\xe0\xcc\x99\x02\xf1\xa2\xcdom_\xaf\xab\x92vw\xb9\xc9\xc3\xec\xb0\x81\xfa\xe9uH\xec\x02\xef\xa33\xb8k]\x97\xe08'
        b"5G\xc8\xec/\x7f\xd6#^\xa8\xcd\xcd\x8bhF\xb0\xe9b\xe3'\x94\xd9|\xa5\xdc\x11U\x9dE\xd7\x90-\x0bf\xdc\xc7\xba\xaf\x99\x10A~\x83\xd8s\xe4\x94\xa1\xba\xfd\xac%\xcc\x1c\xdc\xd0]\xda\x0b\xa5\x8b\x9c\x16#"
        b'\xed\x88\x8dv\xf2z\x8a\x05\xfa:\xef\xd8\x15h\x1ch4\xab\xce\xf6Z)G\x82\xb3\x999cp\xa4^\xcc\xbf\x1fy\x1a\t\xbe\xbe?o\xf5\t\x92v\x16\x8a/\x93a?\xf2\xa3\xbf\x11\x99\x9f \x10\xe8\xb0\x85\xb5\xfe'
        b'\x1e\xe7DcsND\xcc\xef\xff\x18\xe5\xcc\x12=\x9e\xbb6\xc0J\xed\xbf\xeff\n\xbd\\\x8e\xfe\xdde\x9f;_M\xa5`M@f\x01\x00\t\x84\x02\xa4\xd2\xd9\xe61\xedC!-\xcd1\x85SQl3\x9b\x9b%'
        b'\xf6\x8c\x19\x00=\xaeW\x03\\\xe0\x1ev_\x92\xa9\x17:\x84\xdf\x1co\x85\xe3\xcf\x17\n\xe6R\x84\x0e\x87Z\x1c\\5\x99\xc5%~K\xad\x9dJ\xf7\xb3\xdc\xd9+\x1b[\xb7\x9bG\x9b\xd0\xf5\x95\xf9\x17Q\\"f3'
        b'\x00\x97BzR\xdc\xc4\xda}\x8f\xf5\x8e\xc5\xbc\xca*\xa7\xa4U\xf8v\x13\xa6\xb9}4\x1d\x1c\x9d\xb7\xa4_\xb9\xccgYId\xec}\xd64\x16\xb3\x03\xc5\xa7\xbe&\x97I\x13\x81\x99\xe9\x89\xd6\xb6\xbd\xd7M\xe3\x01c'
        b"\x8e\x89_*\xb1u\x1c\xe6#\xde\xb7\xa2'!C\xe6\x9b\x8a\xbe\x03\xe8RQR\x9ds\xff\xb5\xfbu\xe9\xfe\xfe\x05\xf4\xad\xb9i\xa5b\x98\xfb\x8b,\t/.w\x8e\x7f\xce\x8a1\x17\xe4>\xa5\x10\xd9-\\\xbd\xa5 "
        b'\xce\x06\xdbY\x11\x05\x90\xe5\x06*CQ6\xe0q\xe1\x1b\x0cDg\t\xecn_R\xeaK\x7f\xee{\xba\xc7\x97PQU\n3\xb8\x1d\xb0\xa60\xfe>\xbf\xdf\xa4\xbf\xa9\x88)\x8b4g\xcbp\x06\xf5\xd8\xf2\xdd\x04\x18'
        b"Dw\x1e\xb3\xdf\xd0\xe9e\xe4'\x03\x1d\xb4ja/\xc9y\x93J\x91\x94\xcf\xbbN\x167\xb9\x95\xea>\x84\xc53{.\xa6G\xf7&\xa5\x89&\xf3\xa4\xfa\x93U\xe0B\x0b\t\x8b\x11\x99\x06PS\xaaXk?BJ"
        b'\xfe\xeab\xa4Y_n5\x00OPD\x11Wd\x92\xa9J\xf0D\xf8\x17\xa4=\xef\xfa\xb2\xb6\xea\xe0\xa0\xf6\xe6\x82\xac\xc8\xe7\x08J)\x89\xe0\x00\xb183m\x90\x8a.&\xd1\xbc\x948k`\xceqF\xadX\x18\xf1'
        b'\xf4\xe6U\x00\x9b\xaa\x11\xa5Vu)\x91\xfeZe\xc3\xbdBe\xdd\x03}ae\xf7\xf7\x9d\x94\x8a2\x90"\x14\x9c\xa3-bf\x19\x18\x93:\x81\x14o{\x81\xd6\xf9\xbfTk@\x15\xafn\x87\xb8`\xfa5\x81\xe4\xb6'
        b'\xb9\x8f\xcacNa\x82\xf7\xdd\x0e\x1a\xf2!P\x8c<\xd0\x01\xa7xM\xb5\x0f\x91\x1c\xb6\x9f\xa2_:\x91\x12b.4\x81|7\xbc\x95eH\xc1\xe8\xb8\xae8~\xbc\x9b\xc7\xb6\xf0\xa8\xef\xf5\xc0)\x956A\xad5\xaf'
        b'[\xdc\xc8\x91\x9d\x90\xef\xaa~ \x89,\xa5\n\xf9\xb8#h\x94\xcc\xfd`i\x16\x81\xce8j\xb3]\x95 Xp\xf9\xa1\xb4\xa6<]Q\x97\xf0\x07\x17\x1a*\xfc\xc1\x15\n\x9c\xbeQ\xb6c.\xaf\x1a\x95\x10\x87\xe6\xf7'
        b'\xf2.\x04E\xa7\xc2\x82\xd0\xb8\x940\x97\x95\xbfQ\x02\xcf^v\xf3z\xa9\xbc\xcbK\x85-\xabek\xa8L\xbau\x97U\xbd[}t\x9b-\x8aq\xb9{\x9eh5\x84\xc9\xb4r\x07\xc3\x1aq\xdcF\xf0\xd0QA!'
        b'\xd1\xbf\'\xd6\xec\x84M\xff\x9c9\xdbh\xfa\x81i\xa2\xcd\xe2*1\x1e8e\x0f=\xabyC5FXJ\xe6c\x84QL0\xe2\x86\x81\x997\xf19\r"V\xafO(\xb7L\xe7@\xe1\x8b^\xf9\xbb.\xf4\xbe\xb0'
        b'\x9a1\xd7^\x84\xd2|X\x89\xaa\xb0\x81o8\x1b\xd3F;\xcb_\xec\xd2\x80\rMW\xcc@\x87w\xc6;\xaa\xd6B\xd4=\xf2\x9b\x04d\x97\\\xd6\xd0\xe9\x86\xe3\xc5\x9e%Fw\x00&3\xf8$p\xd8\xc5\xd8 \xc7'
        b'\xd1T\x0c\xba\x81l\xadb\xa0\x9f\x8e4\x17\xe8pY\x95\x82Y~6b\x8c\xb2\xde\'\xe147b\xb2_\x9d\xa3@\x84\x8dD\x19xUg\x19\xaf\xb9\xcf\x151\x0e\xf7O"\xeb\xffx\x00\xbe\xf8\x8f2s\x9f\x1e\xae'
        b'\xf4\xf1\x1a\x01+\rc&\x99\x9b\x05\x94\x97j\xc15\xe4\xfb\x11\xe6\x12\xba`\x86\xcc\xfc\x83\x13\xb0\x8a\xa8\xbf7M\x88\x06\t\xcb\x14\xfeE\x07\xee$\xf2d$x\xd1\x8a)3\xa6*\xc8u\x9fR\xdeY!d\xb4I'
        b'\x16\x05{\x8e\x0c\xf4n\xd1X\x85( Bk\x87D*\x0fX%i\x12\xcd\xa2\xad\xefP\xfb\xe7\xa7S\xe7\xb2D\x14\xfd\xa7\xe0\x83/4\x86\xcb\xf1\xe7\xf4\xcc\x90\xeac\x80+\x1d{\xea\xb3I\xff\xc7\xf6\x80\x88\xfa\xc1'
        b'\x9bz\xb7\xbd\x10\n\xe9\x9c\xa8\xceM+3\xe0\x81\xb2<:\xf8\x91\xcd\xd9\xb2\x18\x83\n\x89s\xd2\xa3\xe2)\xe2-\x84\xdc=\x00\xe5\x90\xea\x06\xeeq\x88\xc4vi\x9d\xec\xc8\x8a\x8b"\xf3n\xeb\xaec\xccR~]p'
        b' \xc6\x01\xec!%0;\x92\x06\xa1\\\x90\\\xa9\xc5\x95\xa0$\x122\x89C\x02E.\xf7\xf0x\xf0\xd4Y,[Ag\xd0\r\xff\xd4\xd6}T\xab\xb2\xb1J\xdf#0I\x11\xaa\xae?H\x1aK\xff\xb9\xeb\xaf:~'
        b'\x93\xa0\xca:\x86\x86\x01\xeeS\xcf}b\xb1\xacH\xc33\x1f\x01\x80&\xe88\x03A;\xc6\x8f\x93?R\xae\x0b\x9b\xe3\x07UE\x94\xb8\xdb\x93C\xc1\xaf\x84+?\x92\xd5jm\x03l\x90\xc6\x1d\xde\x88\xd4\x8fn_m'
        b"HTN\xf2\xd8\x9e\xdd1\x0bU\xa3\xa6RYR\x17od\xa5uD\xd9J`\r\x01\xcdxH\x90\x1b\xd3\xce\xdf\xc7t`\xfb\xdb\x1e\xf2\xf6\xfdb\xed\xcf\x87\x17gu\xd9\xf2[8z~\xc6\x04\xcfA\xf5\xe1'\x90"
        b'_\xd1\xaaY\xf8\xeb9H\\\xcay\x16M\xf3\xdbt\xa4\x8f\xac\x14v`\xc0v\x9b\xe0\x96ZQ\x00\x1e\xbd<\xbcG7\xb0\xc9\x05#P/8VKf\x88{\x16\x9a\xa6\xaa\xd4\x06\xe2l+\x086-\xd0\xbdON'
        b'\x10\x99Q\x94\xa4\xeb\xf4\xe2\xe9A\x93\xa5l|8\x89>\xff\xdcf\x9c0\x1b\xf1)\xe3\x0f\xfeB\x93\x16\xe02\xbe\xdf\xf5H\x97\xa6\xa8I\x8aVG\x9a\x83Y\xe9\x10\xc7]\xac9\xee\xc65\x8b\xc7RH;7\xfa\xf5'
        b'\xf0\x9f_\xc8\xf1\xca\x08\xf7g\x1d{\xe1\xefZ\xff\xee\x9f\xc2&\xd09\xeb1\x1f5]\xe4<]\x96\xeb\xeb*\xc8\x03\x07\xed\xad\rhW\xfb\xfb\xb4\xf7A\xef\xc8\xa9!\xe9b\x94:\xc3\xf6\xec\x87\x86$\xde\x95 \x18'
        b'\\\x86\x0c"\xcc\xd4y\xbb\x00K\x08\xcd\x14\x90\xb4\x92\xd2\xb4\x8fa\x9aL\x9e\xdev\xf0n\xe0<+."\x19t\xab\xdb=\xbbL\x98\x95C\xd3\x88\x8f\\j\xe0\xcb0,\xed\x93hZ\xcc7|Y\t-\xe6\xc1\xd1'
        b'R\xe6\x85%wKMJ\xda\x01\xba\xec\xe3\xb0\xa0\x99\x96`\xe2\xa9\xbd"\xa1\xcd$S\xe2\x1b\xda\x93\x06\xb1\\q\x99 ;\x95\xb0Qi\x1c\xb2\xc3\xc2F\x04\xce\xd1\x84\xfb\xb3\xf4\x06\xb8\x11[\xc5\xe0\xe7\x1d\xfd\xd6\x88'
        b'\x01$\xbc\x957Q\xef\xab\xaf\xb9Q\xb1\x95\xe5\xebYS5v\xe3we\x12\x05\x1c\x99\x14\xf3\x01\xb0M\x1djs\x06\xe5Nj\xa1w\x8cQh\x13\xfa\x8f<\xef\xc8\x08T\x1c\xcb\xc9\x13\xfb\xfa\xcd@\x9dN\xe6o\xb6'
        b'\xc6Ox\xbd\xedJ\xa6|\xaf\xb7\x155U\xce\x88\xda\x84M\xd2T\x1d\x91\x13l\xbb\xfe\xbf\x14\xd7k\x14_gI\x7fA\xe4\x02\x87\xb8E\xbfKCP\x04\xee\x02\x08\x84\xae\xf8j\xbe\xff\x91Z\x85\x93\xf7\xa9m\xfal'
        b"\x17\x10k\xb21\x87\xce,\xd2,\xed\x18\xff\xe8O\xfc\xaa\xb4>\xb5\x0f[w4\xf8\xc8W\x90O\xa1z\xe8\xcbgLbxc\x9ed\x03\xb0M\x86\x1d\xb4?\xd9PO\x08\xf9\xbb\r{\x80\xb6\xa0.\x93'$\x9cm"
        b'\xa1>a \xd4\\\x1c\xc1\xdck\x88\n\x0b\xbf_}*\x1b\x86\x9f\\\x18\xc7)V\xca\x88\xe5E\xbb\x02{"\x8d\x08D\xbeT\x9d\xc9\xe1\x97U\rJC[\xcf\r\xd3rR\x0c\x1b\xab\n6\x1b\xe1@\n\x8cs\x83'
        b'\xce\xc2BJ\x17\xc4\xab\xb9\x97V\x18\xfa\xd0\xf7\x91b$\x1f\x1f\xf0F\xed8\x15\xba\xe5\x0c\x02\xe8f\xa4\xb5\x00Y\xe3\x05\xeeC\xf5\x98\r\x0b\x18\xb9&\xd6B\x1b\xba\xd1t\xcc1)\xd6\x03\x81E\xac\xc1-\xd0w\xfd'
        b'\x019\xe4\x13RW]G\xbc#f\x9b\xba\xdf\xda\x9f7\xee\xa2\xc7\x05:\xbd\x10\xa2\xfd\xf6\xefWYZ\xc0\x87T\x13\x81\x90\x0e\xd0~\x1f(\xdd\x0bP\xcc\xecr\x01!\xd6T\xea\xc0~\xa5\xb7\x03`\x9a`.O8'
        b'\xf86w`,\xf8\x1a3\x00y\xb8t"\xf6(\xdf\xcc\xa1q\\\xab\xe9\x01\x00\x00\x00N)\x04Z\x0b__pyarmor__\xda\x0cRuntimeError\xda\x08__name'
        b'__\xda\x08__file__\xa9\x00r\x05\x00\x00\x00r\x05\x00\x00\x00\xfa\x16<frozen fintech.swift>\xda\x08<module>\x01\x00\x00\x00s\x08'
        b'\x00\x00\x00\x02\x00\x08\x01\x06\x00\x0e\x01'
    ))
